Python: module dbdiff

dbdiff | index /tmp/makerelease-pwman-python.NVQhFLFA/pwman-python-2.8/libpwman/dbdiff.py

# Simple password manager
# Copyright (c) 2011-2023 Michael Büsch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.

Modules
difflib |  |  |

Classes
|  | builtins.object PWManDatabaseDiff
class PWManDatabaseDiff(builtins.object)
| PWManDatabaseDiff(db, oldDb)
| Methods defined here: __init__(self, db, oldDb) Initialize self. See help(type(self)) for accurate signature. getContextDiff(self, contextLines=3) getHtmlDiff(self, contextLines=3) getNdiffDiff(self) getUnifiedDiff(self, contextLines=3) Data descriptors defined here: __dict__ dictionary for instance variables (if defined) __weakref__ list of weak references to the object (if defined)

Data
|  | __all__ = ['PWManDatabaseDiff']